@@ -2,8 +2,8 @@ package MooseX::Getopt::Strict;
 BEGIN {
   $MooseX::Getopt::Strict::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $MooseX::Getopt::Strict::VERSION = '0.33';
+{
+  $MooseX::Getopt::Strict::VERSION = '0.45';
 }
 # ABSTRACT: only make options for attrs with the Getopt metaclass
 
@@ -87,11 +87,15 @@ Chris Prather <perigrin@cpan.org>
 
 Karen Etheridge <ether@cpan.org>
 
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2012 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
